Emoji
=====

Emoji is a simple Python module.

This project was inspired by
`emoji <https://github.com/kyokomi/emoji>`__ of
`kyokomi <https://github.com/kyokomi/emoji>`__.

|PyPi version| |PyPi downloads| |PyPi status| |PyPi license|

Installation
------------

To install ndrive, simply:

::

    $ pip install emoji

Or, you can use:

::

    $ easy_install ndrive

Or, you can also install manually:

::

    $ git clone https://github.com/carpedm20/emoji.git
    $ cd emoji
    $ python setup.py install

Example
-------

::

    from emoji import emojize

    print emojize("Python is :thumbsup:")
    print emojize("Do you want some :beer: ?")

Demo
----

.. figure:: https://raw.githubusercontent.com/carpedm20/emoji/master/demo/demo.png
   :alt: demo

   demo
Link
----

`Emoji Cheat Sheet <http://www.emoji-cheat-sheet.com/>`__

Author
------

Taehoon Kim / [@carpedm20](http://carpedm20.github.io/about/)

.. |PyPi version| image:: https://pypip.in/v/emoji/badge.png?style=flat
   :target: https://pypi.python.org/pypi/emoji
.. |PyPi downloads| image:: https://pypip.in/d/emoji/badge.png?style=flat
   :target: https://pypi.python.org/pypi/emoji
.. |PyPi status| image:: https://pypip.in/status/emoji/badge.svg?style=flat
   :target: https://pypi.python.org/pypi/emoji
.. |PyPi license| image:: https://pypip.in/license/emoji/badge.svg?style=flat
   :target: https://pypi.python.org/pypi/emoji
